# APRheology
##### _Toolkit for Anton Paar rheometer data_

The purpose of this program is to facilitate the analysis 
of rheometer data of polymeric samples. The program is originally
designed to use RheoCompass csv exports as input, however, it is 
developed without involvement of Anton Paar and is thus independent
from the company and its RheoCompass software. 

Currently, the extraction of relaxation times from frequency sweep
and stress relaxation experiments is supported. Other functionality might 
be added as needed.

##### License

APRheology is available free of charge under an MIT License. 
See the LICENCE file for more details.


##### Changelog

###### 0.2.2
* Export of advanced tab now possible
* Bugfixes

###### 0.2.0
* Introduce generalised Maxwell model

###### 0.1.4
* Bugfixes

###### 0.1.0
* Initial release



